@@ -466,7 +466,7 @@ static void time_cipher_lrw(void)
    tally_results(1);
 }
 #else
-static void time_cipher_lrw(void) { fprintf(stderr, "NO LRW\n"); return 0; }
+static void time_cipher_lrw(void) { fprintf(stderr, "NO LRW\n"); }
 #endif
 
 
@@ -1463,6 +1463,6 @@ return EXIT_SUCCESS;
 
 }
 
-/* ref:         HEAD -> master, tag: v1.18.1 */
-/* git commit:  e08fd8630f9d9771226466877064055ee7e863d0 */
-/* commit time: 2018-01-22 11:02:57 +0100 */
+/* ref:         HEAD -> master, tag: v1.18.2 */
+/* git commit:  7e7eb695d581782f04b24dc444cbfde86af59853 */
+/* commit time: 2018-07-01 22:49:01 +0200 */
